==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/insert/OpenRepeatAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.insert;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.MeasureCoords;
import org.herac.tuxguitar.gui.undo.undoables.custom.UndoableChangeOpenRepeat;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class OpenRepeatAction extends Action{
    public static final String NAME = "OPEN_REPEAT";
    
    public OpenRepeatAction(TablatureEditor tablatureEditor) {
        super(NAME,true,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
    	UndoableChangeOpenRepeat undoable = UndoableChangeOpenRepeat.startUndo(); 
    	
        MeasureCoords measureCoords = getEditor().getTablature().getCaret().getMeasureCoords();
        getSongManager().changeOpenRepeat(measureCoords.getMeasure().getStart());
        updateTablature();     
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo());
        
        return true;
    }

    protected void updateTablature() {
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();
    }    


}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/insert/OpenRepeatAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.insert;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.editors.tab.MeasureCoords;
import org.herac.tuxguitar.gui.undo.undoables.custom.UndoableChangeOpenRepeat;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class OpenRepeatAction extends Action{
    public static final String NAME = "action.insert.open-repeat";
    
    public OpenRepeatAction(TablatureEditor tablatureEditor) {
        super(NAME,true,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
    	UndoableChangeOpenRepeat undoable = UndoableChangeOpenRepeat.startUndo(); 
    	
        MeasureCoords measureCoords = getEditor().getTablature().getCaret().getMeasureCoords();
        getSongManager().changeOpenRepeat(measureCoords.getMeasure().getStart());
        updateTablature();     
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo());
        
        return true;
    }

    protected void updateTablature() {
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();
    }    


}
